# AppSniffer

AppSniffer is an interactive Python script for fetching information about apps from Google Play Market. 
It allows you to check the app's version, last update date, and other useful details.

## Installation

1. Ensure you have Python 3.6 or higher installed.
2. Install the script using pip:

```bash
pip install .
```

3. Run the script with the command:

```bash
appsniffer
```

## Usage

- Enter the app name to get information.
- Type `q` or `quit` to exit.
- Type `clear` to clear the console.

----

UPDATE 2.0.0

1) Now you can insert a link along with the application name if the desired application cannot be found by name.

----

## Author

- **Avinion**
- Telegram: [@akrim](https://t.me/+VFiT6gd42ehhNzYy)
- Email: shizofrin@gmail.com
- Website: [https://yourwebsite.com](https://t.me/+VFiT6gd42ehhNzYy)

## License

This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for details.